Documentation
¶
Index ¶
- func Error(err error, code string, metadata ...map[string]string) *errors.Error
- func GetLOGO() string
- func Version() string
- type Application
- func (app *Application) Decoder() facade.PacketDecoder
- func (app *Application) DieChan() chan bool
- func (app *Application) Encoder() facade.PacketEncoder
- func (app *Application) IsFrontend() bool
- func (app *Application) IsRunning() bool
- func (app *Application) MessageEncoder() facade.MessageEncoder
- func (app *Application) NodeMode() ServerMode
- func (app *Application) Register(s facade.Service)
- func (app *Application) Serializer() facade.Serializer
- func (app *Application) Shutdown()
- func (app *Application) Start()
- type Option
- type ServerMode
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Application ¶
type Application struct {
// contains filtered or unexported fields
}
func NewApp ¶
func NewApp(opts ...Option) *Application
func (*Application) Decoder ¶
func (app *Application) Decoder() facade.PacketDecoder
func (*Application) DieChan ¶
func (app *Application) DieChan() chan bool
func (*Application) Encoder ¶
func (app *Application) Encoder() facade.PacketEncoder
func (*Application) IsFrontend ¶
func (app *Application) IsFrontend() bool
func (*Application) IsRunning ¶
func (app *Application) IsRunning() bool
func (*Application) MessageEncoder ¶
func (app *Application) MessageEncoder() facade.MessageEncoder
func (*Application) NodeMode ¶
func (app *Application) NodeMode() ServerMode
func (*Application) Register ¶
func (app *Application) Register(s facade.Service)
func (*Application) Serializer ¶
func (app *Application) Serializer() facade.Serializer
func (*Application) Shutdown ¶
func (app *Application) Shutdown()
func (*Application) Start ¶
func (app *Application) Start()
type Option ¶
type Option func(app *Application) error
Option is a function on the options for a connection.
func WithClusterMode ¶
func WithClusterMode() Option
type ServerMode ¶
type ServerMode byte
ServerMode represents a server mode
const ( // Cluster represents a server running with connection to other servers Cluster ServerMode // Standalone represents a server running without connection to other servers Standalone )
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
_examples
|
|
|
chat
command
|
|
|
child
command
|
|
|
helloworld
command
|
|
|
middleware
command
|
|
|
request
command
|
|
|
router
command
|
|
|
net
|
|
|
message/mocks
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
|
queue
|
|
|
mpsc
Package mpsc provides an efficient implementation of a multi-producer, single-consumer lock-free queue.
|
Package mpsc provides an efficient implementation of a multi-producer, single-consumer lock-free queue. |
Click to show internal directories.
Click to hide internal directories.